abacusai.model_monitor_version_metric_data — AbacusAI documentation

# `abacusai.model_monitor_version_metric_data`

## Module Contents

### Classes

`ModelMonitorVersionMetricData` | Data for displaying model monitor version metric data

class abacusai.model_monitor_version_metric_data.ModelMonitorVersionMetricData(client, name=None, algoName=None, featureGroupVersion=None, modelMonitor=None, modelMonitorVersion=None, metricInfos=None, metricNames=None, metrics=None, metricCharts=None, otherMetrics=None, actualValuesSupportedForDrilldown=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Data for displaying model monitor version metric data

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the metric type

    - algoName (str) – The name of the algo used for the prediction metric

    - featureGroupVersion (str) – The prediction feature group used for analysis

    - modelMonitor (str) – The id of the model monitor

    - modelMonitorVersion (str) – The id of the model monitor version

    - metricInfos (dict) – Name and description for metrics

    - metricNames (dict) – Internal name to external name mapping

    - metrics (dict) – Metric name to metric data

    - metricCharts (list) – List of different metric charts

    - otherMetrics (list) – List of other metrics to optionally plot

    - actualValuesSupportedForDrilldown (list) – List of values support for drilldown

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict